class atasozu:

    def __init__(self, ontaki, madde):
        self.onTaki=ontaki
        self.icerik=madde

    # Atasözünün ön takısını str olarak döndürür.
    # Returns the prefix of the adage as str.
    def ontaki(self):
        return self.onTaki

    # Atasözünün kendisini str olarak döndürür.
    # Returns the adage itself as str.
    def atasozu(self):
        return self.icerik
